@@ -2,8 +2,6 @@ package DB::Introspector;
 
 use strict;
 
-$DB::Introspector::VERSION = '0.05';
-
 use DBI;
 use Config::Properties;
 use IO::File;
@@ -15,54 +13,18 @@ use vars qw( %REGISTRY %INC );
 DB::Introspector->register_drivers();
 
 
-
-sub lookup_table {
+sub find_table {
     my $self = shift;
-    die("lookup_table method not defined in ". (ref($self) || $self)); 
-}
-
-sub lookup_all_tables {
-    my $self = shift;
-    die("lookup_all_tables method not defined in ". (ref($self) || $self)); 
+    die("find_table method not defined in ". (ref($self) || $self)); 
 }
 
 
 sub find_all_tables {
     my $self = shift;
-
-    unless( $self->_looked_up_all_tables ) {
-        foreach my $table ($self->lookup_all_tables) {
-            $self->_cache_table($table);
-        }
-        $self->_looked_up_all_tables(1);
-    }
-    return $self->_get_all_cached_tables;
+    die("find_all_tables method not defined in ". (ref($self) || $self)); 
 }
 
-sub _get_all_cached_tables {
-    my $self = shift;
-    my @tables = values %{$self->{_table_cache}};
-    return @tables;
-}
 
-sub _looked_up_all_tables {
-    my $self = shift;
-    if(@_) {
-        $self->{_looked_up_all_tables} = shift;
-    }
-    return $self->{_looked_up_all_tables};
-}
-
-sub find_table {
-    my $self = shift;
-    my $table_name = shift;
-
-    unless(defined $self->_cached_table($table_name)) {
-        my $table = $self->lookup_table($table_name);
-        $self->_cache_table($table) if( defined $table );
-    }
-    return $self->_cached_table($table_name);
-}
 
 sub register_drivers {
     my $class = shift;
@@ -136,8 +98,6 @@ sub new {
         _dbh => $dbh
     }, ref($class) || $class);
 
-    $self->{_table_cache} = {};
-
     $self;
 }
 
@@ -146,40 +106,7 @@ sub dbh {
     return $self->{_dbh};
 }
 
-sub _clear_dbh {
-    my $self = shift;
-    delete $self->{_dbh};
-}
 
-sub _set_dbh {
-    my $self = shift;
-    if( @_ ) {
-        my $dbh = shift;
-        unless( UNIVERSAL::isa($dbh, 'DBI::db') ) {
-            die("$dbh is not a DBI::db");
-        }
-        $self->{_dbh} = $dbh;
-    }
-
-}
-
-sub _cached_table {
-    my $self = shift;
-    my $table_name = shift;
-    return $self->{_table_cache}{$table_name};
-}
-
-use Carp qw( cluck );
-sub _cache_table {
-    my $self = shift;
-
-    # TODO: Add some type checking here 
-    if(@_) {
-        my $table = shift;
-cluck($table) unless ref $table;
-        $self->{_table_cache}{$table->name} = $table;
-    }
-}
 
 1;
 __END__
@@ -190,38 +117,25 @@ DB::Introspector
 
 =head1 SYNOPSIS
 
- use DB::Introspector;
- 
- my $introspector = DB::Introspector->get_instance($dbh);
- 
- my $table = $introspector->find_table('foo');
- 
- print $table->name;
+=over 4
 
- # showing the table's indexes
- foreach my $index ($table->indexes) {
-     print $index->name.": (".join(",",$index->column_names).")\n";
- }
+use DB::Introspector;
 
- # showing the table's foreign keys
- foreach my $foreign_key ($table->foreign_keys) {
+my $introspector = DB::Introspector->get_instance($dbh);
 
-     print $foreign_key->foreign_table->name;
+my $table = $introspector->find_table('foo');
 
-     print join(",",$foreign_key->foreign_column_names);
+print $table->name;
 
- }
+foreach my $foreign_key ($table->foreign_keys) {
+    print $foreign_key->foreign_table->name;
+    print join(",",$foreign_key->foreign_column_names);
+}
 
- # showing foreign keys that reference this table ('foo')
- foreach my $foreign_key ($table->dependencies) {
-     print "Some other table :".$foreign_key->local_table->name
-          ." is pointing to me\n";
- }
- 
- my @tables = $introspector->find_tables;
-
- # you can do other cool stuff; just read the docs.
+my @tables = $introspector->find_tables;
 
+=back
+     
 =head1 DESCRIPTION
 
 DB::Introspector looks into database metadata and derives detailed table level
@@ -264,7 +178,7 @@ Returns: An array (@) of DB::Introspector::Base::Table instances for each table
 
 =back
 
-=back
+
 
 
 =head1 METHODS
